compute_conformance

Function compute_conformance 

pub fn compute_conformance(net: &PetriNet, sequences: &[CallSequence]) -> f64
Compute the fraction of sequences that conform to net. Sequences with <2 calls trivially conform. Returns 0.0 when sequences is empty or the net has no arcs.